mod valid;
use crate::{Rectangle, Square, Triangle, ValidShape, Vector};
use num_traits::{Num, Zero};
